@@ -1,5 +1,5 @@
-maxnodenum<-function(dendat,h,N,n,d){
-#
+maxnodenum<-function(dendat,h,N,n,d)
+{
 minim<-matrix(0,d,1)
 maxim<-matrix(0,d,1)
 i<-1
@@ -13,6 +13,7 @@ delta<-(maxim-minim+2*hmax)/(N+1)
 mindelta<-min(delta)
 maxpositive<-ceiling(n*(2*hmax/mindelta)^d)
 bigd<-sum(log(N,base=2))
-maxnode<-bigd*ceiling(maxpositive)
+maxnode<-ceiling(bigd*maxpositive)
+
 return(list(maxnode=maxnode,maxpositive=maxpositive));
 }
