@@ -3,10 +3,11 @@ sim.mulmod<-function(n=NULL,seed=1,N=NULL)
 d<-2
 mnum<-3
 D<-3.5  #3 
+shift<-0.2  
 M<-matrix(0,mnum,d)
 M[1,]<-c(0,0)
-M[2,]<-c(D,0)
-M[3,]<-c(D/2,D)       #c(D/2,D*sqrt(3)/2)
+M[2,]<-c(D,shift)   #c(D,0)
+M[3,]<-c(D/2,D)    #   #c(D/2,D*sqrt(3)/2)
 sig<-matrix(1,mnum,d)
 p<-c(.25,.35,.45)
 p<-p/sum(p)
